aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--contrib/telnet/arpa/telnet.h2
-rw-r--r--crypto/telnet/arpa/telnet.h2
-rw-r--r--lib/libstand/ext2fs.c2
-rw-r--r--lib/libz/minigzip.c2
-rw-r--r--libexec/rshd/rshd.c2
-rw-r--r--release/texts/alpha/RELNOTES.TXT2
-rw-r--r--release/texts/i386/RELNOTES.TXT2
-rw-r--r--sys/conf/files.i3862
-rw-r--r--sys/conf/files.pc982
-rw-r--r--sys/dev/dpt/dpt.h2
-rw-r--r--sys/i386/include/if_wl_wavelan.h2
-rw-r--r--sys/i386/isa/isa_compat.c2
-rw-r--r--sys/i386/isa/istallion.c4
-rw-r--r--sys/i386/isa/stallion.c4
-rw-r--r--sys/kern/kern_prot.c6
-rw-r--r--sys/net/if.h8
-rw-r--r--sys/netinet6/nd6.h2
-rw-r--r--sys/sys/poll.h2
-rw-r--r--sys/sys/time.h2
-rw-r--r--usr.bin/brandelf/brandelf.c4
-rw-r--r--usr.bin/doscmd/emuint.c4
-rw-r--r--usr.bin/telnet/README2
-rw-r--r--usr.bin/tsort/tsort.c2
-rw-r--r--usr.sbin/pppd/options.c2
-rw-r--r--usr.sbin/ypbind/yp_ping.c2
25 files changed, 34 insertions, 34 deletions
diff --git a/contrib/telnet/arpa/telnet.h b/contrib/telnet/arpa/telnet.h
index d7942671db31..b8d3856727b8 100644
--- a/contrib/telnet/arpa/telnet.h
+++ b/contrib/telnet/arpa/telnet.h
@@ -214,7 +214,7 @@ char *telopts[NTELOPTS+1] = {
#define NSLC 30
/*
- * For backwards compatability, we define SLC_NAMES to be the
+ * For backwards compatibility, we define SLC_NAMES to be the
* list of names if SLC_NAMES is not defined.
*/
#define SLC_NAMELIST "0", "SYNCH", "BRK", "IP", "AO", "AYT", "EOR", \
diff --git a/crypto/telnet/arpa/telnet.h b/crypto/telnet/arpa/telnet.h
index d7942671db31..b8d3856727b8 100644
--- a/crypto/telnet/arpa/telnet.h
+++ b/crypto/telnet/arpa/telnet.h
@@ -214,7 +214,7 @@ char *telopts[NTELOPTS+1] = {
#define NSLC 30
/*
- * For backwards compatability, we define SLC_NAMES to be the
+ * For backwards compatibility, we define SLC_NAMES to be the
* list of names if SLC_NAMES is not defined.
*/
#define SLC_NAMELIST "0", "SYNCH", "BRK", "IP", "AO", "AYT", "EOR", \
diff --git a/lib/libstand/ext2fs.c b/lib/libstand/ext2fs.c
index 1303255486ae..6c05cf5a5cfa 100644
--- a/lib/libstand/ext2fs.c
+++ b/lib/libstand/ext2fs.c
@@ -199,7 +199,7 @@ struct ext2fs_disk {
u_int16_t fd_nblkgrp; /* block group # of superblock */
u_int32_t fd_fcompat; /* compatible features */
u_int32_t fd_fincompat; /* incompatible features */
- u_int32_t fd_frocompat; /* read-only compatabilties */
+ u_int32_t fd_frocompat; /* read-only compatibilties */
u_int8_t fd_uuid[16]; /* volume uuid */
char fd_volname[16]; /* volume name */
char fd_fsmnt[64]; /* name last mounted on */
diff --git a/lib/libz/minigzip.c b/lib/libz/minigzip.c
index e8a61b13e711..7c7246415358 100644
--- a/lib/libz/minigzip.c
+++ b/lib/libz/minigzip.c
@@ -300,7 +300,7 @@ int main(argc, argv)
while (argc > 0) {
if (strcmp(*argv, "-c") == 0)
- ; /* Just for compatability with gzip */
+ ; /* Just for compatibility with gzip */
else if (strcmp(*argv, "-d") == 0)
uncompr = 1;
else if (strcmp(*argv, "-f") == 0)
diff --git a/libexec/rshd/rshd.c b/libexec/rshd/rshd.c
index 50ecad22dafc..20f794a17411 100644
--- a/libexec/rshd/rshd.c
+++ b/libexec/rshd/rshd.c
@@ -131,7 +131,7 @@ main(argc, argv)
while ((ch = getopt(argc, argv, OPTIONS)) != -1)
switch (ch) {
case 'a':
- /* ignored for compatability */
+ /* ignored for compatibility */
break;
case 'l':
__check_rhosts_file = 0;
diff --git a/release/texts/alpha/RELNOTES.TXT b/release/texts/alpha/RELNOTES.TXT
index f17d44d1770f..5ab3deafda7b 100644
--- a/release/texts/alpha/RELNOTES.TXT
+++ b/release/texts/alpha/RELNOTES.TXT
@@ -544,7 +544,7 @@ mergemaster(8) has gained some new features, has been cleaned up
somewhat, and is now more cross-platform friendly.
The compiler chain now uses the FSF-supplied C/C++ runtime
-initialization code. This change brings about better compatability
+initialization code. This change brings about better compatibility
with code generated from the various egcs and gcc ports, as well as
the stock public FSF source. [MERGED]
diff --git a/release/texts/i386/RELNOTES.TXT b/release/texts/i386/RELNOTES.TXT
index b4cf9d6862ef..69f192eb59b6 100644
--- a/release/texts/i386/RELNOTES.TXT
+++ b/release/texts/i386/RELNOTES.TXT
@@ -642,7 +642,7 @@ mergemaster(8) has gained some new features, has been cleaned up
somewhat, and is now more cross-platform friendly.
The compiler chain now uses the FSF-supplied C/C++ runtime
-initialization code. This change brings about better compatability
+initialization code. This change brings about better compatibility
with code generated from the various egcs and gcc ports, as well as
the stock public FSF source. [MERGED]
diff --git a/sys/conf/files.i386 b/sys/conf/files.i386
index a6537e175125..845e85abc69f 100644
--- a/sys/conf/files.i386
+++ b/sys/conf/files.i386
@@ -227,7 +227,7 @@ i386/isa/intr_machdep.c standard
i386/isa/ithread.c standard
i386/isa/isa.c optional isa
i386/isa/isa_compat.c optional isa compat_oldisa \
- warning "Old ISA driver compatability shims present."
+ warning "Old ISA driver compatibility shims present."
i386/isa/isa_dma.c optional isa
i386/isa/istallion.c optional stli
i386/isa/loran.c optional loran
diff --git a/sys/conf/files.pc98 b/sys/conf/files.pc98
index ded0df120817..4ffce8ccfa3c 100644
--- a/sys/conf/files.pc98
+++ b/sys/conf/files.pc98
@@ -220,7 +220,7 @@ i386/isa/intr_machdep.c standard
i386/isa/ithread.c standard
i386/isa/isa.c optional isa
i386/isa/isa_compat.c optional isa compat_oldisa \
- warning "Old ISA driver compatability shims present."
+ warning "Old ISA driver compatibility shims present."
i386/isa/istallion.c optional stli
i386/isa/loran.c optional loran
i386/isa/matcd/matcd.c count matcd
diff --git a/sys/dev/dpt/dpt.h b/sys/dev/dpt/dpt.h
index 6d6230e75014..8798f7650983 100644
--- a/sys/dev/dpt/dpt.h
+++ b/sys/dev/dpt/dpt.h
@@ -904,7 +904,7 @@ typedef struct dpt_ccb {
} dpt_ccb_t;
/*
- * This is provided for compatability with UnixWare only.
+ * This is provided for compatibility with UnixWare only.
* Some of the fields may be bogus.
* Others may have a totally different meaning.
*/
diff --git a/sys/i386/include/if_wl_wavelan.h b/sys/i386/include/if_wl_wavelan.h
index 63c5a93f7d9b..ad7d28e65e6b 100644
--- a/sys/i386/include/if_wl_wavelan.h
+++ b/sys/i386/include/if_wl_wavelan.h
@@ -112,7 +112,7 @@
#define WLPSA_UNIMAC 0x10 /* Universal MAC address */
#define WLPSA_LOCALMAC 0x16 /* Locally configured MAC address */
#define WLPSA_MACSEL 0x1c /* MAC selector */
-#define WLPSA_COMPATNO 0x1d /* compatability number */
+#define WLPSA_COMPATNO 0x1d /* compatibility number */
#define WLPSA_THRESH 0x1e /* RF modem threshold preset */
#define WLPSA_FEATSEL 0x1f /* feature select */
#define WLPSA_SUBBAND 0x20 /* subband selector */
diff --git a/sys/i386/isa/isa_compat.c b/sys/i386/isa/isa_compat.c
index 8dd1bece49ed..099e0b9fb0de 100644
--- a/sys/i386/isa/isa_compat.c
+++ b/sys/i386/isa/isa_compat.c
@@ -245,7 +245,7 @@ isa_compat_attach(device_t dev)
printf("isa_compat_attach: failed to setup intr: %d\n",
error);
}
- device_printf(dev, "driver is using old-style compatability shims\n");
+ device_printf(dev, "driver is using old-style compatibility shims\n");
return 0;
}
diff --git a/sys/i386/isa/istallion.c b/sys/i386/isa/istallion.c
index 36932b90177c..61b7a5087060 100644
--- a/sys/i386/isa/istallion.c
+++ b/sys/i386/isa/istallion.c
@@ -121,7 +121,7 @@
/*
* Define the important minor number break down bits. These have been
- * chosen to be "compatable" with the standard sio driver minor numbers.
+ * chosen to be "compatible" with the standard sio driver minor numbers.
* Extra high bits are used to distinguish between boards and also for
* really high port numbers (> 32).
*/
@@ -1202,7 +1202,7 @@ STATIC int stliioctl(dev_t dev, unsigned long cmd, caddr_t data, int flag,
}
/*
- * Deal with 4.3 compatability issues if we have too...
+ * Deal with 4.3 compatibility issues if we have too...
*/
#if defined(COMPAT_43) || defined(COMPAT_SUNOS)
if (1) {
diff --git a/sys/i386/isa/stallion.c b/sys/i386/isa/stallion.c
index 2d35463c202e..73c2ce19b387 100644
--- a/sys/i386/isa/stallion.c
+++ b/sys/i386/isa/stallion.c
@@ -117,7 +117,7 @@ static unsigned int stl_irqshared = 0;
/*
* Define the important minor number break down bits. These have been
- * chosen to be "compatable" with the standard sio driver minor numbers.
+ * chosen to be "compatible" with the standard sio driver minor numbers.
* Extra high bits are used to distinguish between boards.
*/
#define STL_CALLOUTDEV 0x80
@@ -990,7 +990,7 @@ STATIC int stlioctl(dev_t dev, unsigned long cmd, caddr_t data, int flag,
}
/*
- * Deal with 4.3 compatability issues if we have too...
+ * Deal with 4.3 compatibility issues if we have too...
*/
#if defined(COMPAT_43) || defined(COMPAT_SUNOS)
if (1) {
diff --git a/sys/kern/kern_prot.c b/sys/kern/kern_prot.c
index a5b505fbd290..7238499722b0 100644
--- a/sys/kern/kern_prot.c
+++ b/sys/kern/kern_prot.c
@@ -372,7 +372,7 @@ setpgid(curp, uap)
/*
* Use the clause in B.4.2.2 that allows setuid/setgid to be 4.2/4.3BSD
- * compatable. It says that setting the uid/gid to euid/egid is a special
+ * compatible. It says that setting the uid/gid to euid/egid is a special
* case of "appropriate privilege". Once the rules are expanded out, this
* basically means that setuid(nnn) sets all three id's, in all permitted
* cases unless _POSIX_SAVED_IDS is enabled. In that case, setuid(getuid())
@@ -402,7 +402,7 @@ setuid(p, uap)
*
* Note that setuid(geteuid()) is a special case of
* "appropriate privileges" in appendix B.4.2.2. We need
- * to use this clause to be compatable with traditional BSD
+ * to use this clause to be compatible with traditional BSD
* semantics. Basically, it means that "setuid(xx)" sets all
* three id's (assuming you have privs).
*
@@ -519,7 +519,7 @@ setgid(p, uap)
*
* Note that setgid(getegid()) is a special case of
* "appropriate privileges" in appendix B.4.2.2. We need
- * to use this clause to be compatable with traditional BSD
+ * to use this clause to be compatible with traditional BSD
* semantics. Basically, it means that "setgid(xx)" sets all
* three id's (assuming you have privs).
*
diff --git a/sys/net/if.h b/sys/net/if.h
index 8afeac026853..bcc10adaf28a 100644
--- a/sys/net/if.h
+++ b/sys/net/if.h
@@ -39,7 +39,7 @@
/*
* <net/if.h> does not depend on <sys/time.h> on most other systems. This
- * helps userland compatability. (struct timeval ifi_lastchange)
+ * helps userland compatibility. (struct timeval ifi_lastchange)
*/
#ifndef _KERNEL
#include <sys/time.h>
@@ -109,7 +109,7 @@ struct if_data {
*/
struct if_msghdr {
u_short ifm_msglen; /* to skip over non-understood messages */
- u_char ifm_version; /* future binary compatability */
+ u_char ifm_version; /* future binary compatibility */
u_char ifm_type; /* message type */
int ifm_addrs; /* like rtm_addrs */
int ifm_flags; /* value of if_flags */
@@ -123,7 +123,7 @@ struct if_msghdr {
*/
struct ifa_msghdr {
u_short ifam_msglen; /* to skip over non-understood messages */
- u_char ifam_version; /* future binary compatability */
+ u_char ifam_version; /* future binary compatibility */
u_char ifam_type; /* message type */
int ifam_addrs; /* like rtm_addrs */
int ifam_flags; /* value of ifa_flags */
@@ -137,7 +137,7 @@ struct ifa_msghdr {
*/
struct ifma_msghdr {
u_short ifmam_msglen; /* to skip over non-understood messages */
- u_char ifmam_version; /* future binary compatability */
+ u_char ifmam_version; /* future binary compatibility */
u_char ifmam_type; /* message type */
int ifmam_addrs; /* like rtm_addrs */
int ifmam_flags; /* value of ifa_flags */
diff --git a/sys/netinet6/nd6.h b/sys/netinet6/nd6.h
index be1264d6d8d0..26f58b50a991 100644
--- a/sys/netinet6/nd6.h
+++ b/sys/netinet6/nd6.h
@@ -197,7 +197,7 @@ struct nd_prefix {
*/
struct inet6_ndpr_msghdr {
u_short inpm_msglen; /* to skip over non-understood messages */
- u_char inpm_version; /* future binary compatability */
+ u_char inpm_version; /* future binary compatibility */
u_char inpm_type; /* message type */
struct in6_addr inpm_prefix;
u_long prm_vltim;
diff --git a/sys/sys/poll.h b/sys/sys/poll.h
index 9358c122226a..bacef36e2002 100644
--- a/sys/sys/poll.h
+++ b/sys/sys/poll.h
@@ -32,7 +32,7 @@
#define _SYS_POLL_H_
/*
- * This file is intended to be compatable with the traditional poll.h.
+ * This file is intended to be compatible with the traditional poll.h.
*/
/*
diff --git a/sys/sys/time.h b/sys/sys/time.h
index 74274f824bab..16b1249baed7 100644
--- a/sys/sys/time.h
+++ b/sys/sys/time.h
@@ -120,7 +120,7 @@ struct timezone {
#endif /* _KERNEL */
-#ifndef _KERNEL /* NetBSD/OpenBSD compatable interfaces */
+#ifndef _KERNEL /* NetBSD/OpenBSD compatible interfaces */
#define timerclear(tvp) (tvp)->tv_sec = (tvp)->tv_usec = 0
#define timerisset(tvp) ((tvp)->tv_sec || (tvp)->tv_usec)
diff --git a/usr.bin/brandelf/brandelf.c b/usr.bin/brandelf/brandelf.c
index 3ae4bdf7d0e2..ec591e687204 100644
--- a/usr.bin/brandelf/brandelf.c
+++ b/usr.bin/brandelf/brandelf.c
@@ -67,7 +67,7 @@ main(int argc, char **argv)
switch (ch) {
case 'f':
if (change)
- errx(1, "f option incompatable with t option");
+ errx(1, "f option incompatible with t option");
force = 1;
type = atoi(optarg);
if (errno == ERANGE || type < 0 || type > 255) {
@@ -85,7 +85,7 @@ main(int argc, char **argv)
break;
case 't':
if (force)
- errx(1, "t option incompatable with f option");
+ errx(1, "t option incompatible with f option");
change = 1;
strtype = optarg;
break;
diff --git a/usr.bin/telnet/README b/usr.bin/telnet/README
index b23396efb536..5bec40d8848a 100644
--- a/usr.bin/telnet/README
+++ b/usr.bin/telnet/README
@@ -277,7 +277,7 @@ Februrary 22, 1991:
source route code is automatically enabled.
The NO_GETTYTAB #define has been removed; there
- is a compatability routine that can be built into
+ is a compatibility routine that can be built into
libtelnet to achive the same results.
The server, telnetd, has been switched to use getopt()
diff --git a/usr.bin/tsort/tsort.c b/usr.bin/tsort/tsort.c
index 2f73a80d1fe9..746ea4f3f888 100644
--- a/usr.bin/tsort/tsort.c
+++ b/usr.bin/tsort/tsort.c
@@ -67,7 +67,7 @@ static char sccsid[] = "@(#)tsort.c 8.3 (Berkeley) 5/4/95";
* tsort [-dlq] [inputfile]
* If no input file is specified, standard input is read.
*
- * Should be compatable with AT&T tsort HOWEVER the output is not identical
+ * Should be compatible with AT&T tsort HOWEVER the output is not identical
* (i.e. for most graphs there is more than one sorted order, and this tsort
* usually generates a different one then the AT&T tsort). Also, cycle
* reporting seems to be more accurate in this version (the AT&T tsort
diff --git a/usr.sbin/pppd/options.c b/usr.sbin/pppd/options.c
index 0676e3c72a4e..2b70bc0e8ccd 100644
--- a/usr.sbin/pppd/options.c
+++ b/usr.sbin/pppd/options.c
@@ -2234,7 +2234,7 @@ setdeflate(argv)
} else
ccp_allowoptions[0].deflate = 0;
- /* XXX copy over settings for switch compatability */
+ /* XXX copy over settings for switch compatibility */
ccp_wantoptions[0].baddeflate = ccp_wantoptions[0].deflate;
ccp_wantoptions[0].baddeflate_size = ccp_wantoptions[0].deflate_size;
ccp_allowoptions[0].baddeflate = ccp_allowoptions[0].deflate;
diff --git a/usr.sbin/ypbind/yp_ping.c b/usr.sbin/ypbind/yp_ping.c
index a88d8ff1c15d..558843f0c7fc 100644
--- a/usr.sbin/ypbind/yp_ping.c
+++ b/usr.sbin/ypbind/yp_ping.c
@@ -98,7 +98,7 @@ static const char rcsid[] =
#ifndef timeradd
#ifndef _KERNEL /* use timevaladd/timevalsub in kernel */
-/* NetBSD/OpenBSD compatable interfaces */
+/* NetBSD/OpenBSD compatible interfaces */
#define timeradd(tvp, uvp, vvp) \
do { \
(vvp)->tv_sec = (tvp)->tv_sec + (uvp)->tv_sec; \
diff --git a/usr.bin/doscmd/emuint.c b/usr.bin/doscmd/emuint.c
index 750a6f9ee06a..8e321c0cbcf2 100644
--- a/usr.bin/doscmd/emuint.c
+++ b/usr.bin/doscmd/emuint.c
@@ -92,14 +92,14 @@ emuint(regcontext_t *REGS)
/*
* XXX
* temporary backwards compatability with instbsdi.exe
* remove after a while.
*/
fprintf(stderr, "***\n*** WARNING - unknown emuint function\n");
fprintf(stderr, "*** Continuing; assuming instbsdi redirector.\n");
fprintf(stderr, "*** Please install the new redirector");
fprintf(stderr, " `redir.com' as soon as possible.\n");
- fprintf(stderr, "*** This compatability hack is not permanent.\n");
+ fprintf(stderr, "*** This compatibility hack is not permanent.\n");
fprintf(stderr, "***\n");
PUSH(R_AX, REGS);
R_BX = R_ES;
@@ -92,14 +92,14 @@ emuint(regcontext_t *REGS)
/*
* XXX
- * temporary backwards compatability with instbsdi.exe
+ * temporary backwards compatibility with instbsdi.exe
* remove after a while.
*/